<?php
// Own namespace
namespace CoreFramework\Stream\Crypto;

// Import framework stuff
use CoreFramework\Generic\UnsupportedOperationException;
use CoreFramework\Stream\BaseStream;

/**
 * A null-encryption stream does not encrypt anything but can be used if e.e.
 * mcrypt is not installed.
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009  Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class NullCryptoStream extends BaseStream implements EncryptableStream {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Creates an instance of this node class
	 *
	 * @return	$streamInstance		An instance of this node class
	 */
	public static final function createNullCryptoStream () {
		// Get a new instance
		$streamInstance = new NullCryptoStream();

		// Return the instance
		return $streamInstance;
	}

	/**
	 * Encrypt the string with fixed salt
	 *
	 * @param	$str		The unencrypted string
	 * @param	$key		Optional key, if none provided, a random key will be generated
	 * @return	$encrypted	Encrypted string
	 */
	public function encryptStream ($str, $key = NULL) {
		// Just handle it over
		$encrypted = (string) $str;

		// Return it
		return $encrypted;
	}

	/**
	 * Decrypt the string with fixed salt
	 *
	 * @param	$encrypted	Encrypted string
	 * @return	$str		The unencrypted string
	 */
	public function decryptStream ($encrypted) {
		// Just handle it over
		$str = (string) $encrypted;

		// Return it
		return $str;
	}

	/**
	 * Streams the data and maybe does something to it
	 *
	 * @param	$data	The data (string mostly) to "stream"
	 * @return	$data	The data (string mostly) to "stream"
	 * @throws	UnsupportedOperationException	If this method is called (which is a mistake)
	 */
	public function streamData ($data) {
		self::createDebugInstance(__CLASS__, __LINE__)->debugOutput('Unhandled ' . strlen($data) . ' bytes in this stream.');
		throw new UnsupportedOperationException(array($this, __FUNCTION__), self::EXCEPTION_UNSPPORTED_OPERATION);
	}

}
