<?php
// Own namespace
namespace CoreFramework\User\Points;

// Import framework stuff
use CoreFramework\Criteria\Add\AddableCriteria;

/**
 * An interface for bookable points
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2017 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
interface BookablePoints extends AddableCriteria {
	/**
	 * Checks whether the user has the required amount of points left for the specified action
	 *
	 * @param	$action			The action or configuration entry plus prefix the user wants to perform
	 * @return	$hasRequired	Whether the user has the required points
	 */
	function ifUserHasRequiredPoints ($action);

	/**
	 * "Books" the given points amount on the current user's account
	 *
	 * @param	$amount		Amount of points we shall book
	 * @return	void
	 */
	function bookPointsDirectly ($amount);

}
